# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [Unreleased]

### Added
- Your new feature here.

### Changed
- Your change here.

### Deprecated
- Your deprecated feature here.

### Removed
- Your removed feature here.

### Fixed
- Your bug fix here.

### Security
- Your security fix here.

## [0.5.0] - 2025-10-26

### Added
- Initial release of `kinemotion`.
